@@ -3,15 +3,15 @@ from fss3wrap.abstract_fs_class import AbstractFSClass
 from fs import open_fs
 from fs.base import FS
 from fs.copy import copy_file
+import boto3
 
 import ntpath
 
-
 class S3FsClass(AbstractFSClass):
 
     os_fs = None
     s3_fs = None
-
+    bucket = None
     def __init__(self, s3_parameters, bucket=None, rootdir=None):
         self.reinit(s3_parameters, bucket, rootdir)
 
@@ -23,6 +23,17 @@ class S3FsClass(AbstractFSClass):
     def directory_list(self, path):
         return self.s3_fs.listdir(path)
 
+    def directory_list_v2(self, path, filter):
+        session = boto3.Session(aws_access_key_id=self.s3_parameters['access_key_id'],
+                                aws_secret_access_key=self.s3_parameters['secret_access_key'])
+        s3_obj = session.client('s3')
+        # Return max 1000keys
+        prefix, suffix = filter.split('*')[0], filter.split('*')[1]
+        kwargs = {'Bucket': self.bucket, 'StartAfter': path, 'Prefix': path+prefix}
+        resp = s3_obj.list_objects_v2(**kwargs)
+        paths = [elem['Key'] for elem in resp['Contents'] if elem['Key'].endswith(suffix)]
+        return paths
+
     def download(self, source_path, dest_path, filename, mode):
         if mode == 'b':
             file_content = self.file_read_bin(source_path, filename)
@@ -88,3 +99,8 @@ class S3FsClass(AbstractFSClass):
                 bucket if bucket is not None else s3_parameters['bucket']
             )
         )
+        self.s3_parameters = s3_parameters
+        self.bucket = bucket if bucket is not None else s3_parameters['bucket']
+
+
+
